@@ -1,7 +1,6 @@
-
 from novaclient.v1_1 import images
-from tests.v1_1 import fakes
 from tests import utils
+from tests.v1_1 import fakes
 
 
 cs = fakes.FakeClient()
@@ -19,6 +18,10 @@ class ImagesTest(utils.TestCase):
         cs.assert_called('GET', '/images')
         [self.assertTrue(isinstance(i, images.Image)) for i in il]
 
+    def test_list_images_with_limit(self):
+        il = cs.images.list(limit=4)
+        cs.assert_called('GET', '/images/detail?limit=4')
+
     def test_get_image_details(self):
         i = cs.images.get(1)
         cs.assert_called('GET', '/images/1')
@@ -30,6 +33,15 @@ class ImagesTest(utils.TestCase):
         cs.images.delete(1)
         cs.assert_called('DELETE', '/images/1')
 
+    def test_delete_meta(self):
+        cs.images.delete_meta(1, {'test_key': 'test_value'})
+        cs.assert_called('DELETE', '/images/1/metadata/test_key')
+
+    def test_set_meta(self):
+        cs.images.set_meta(1, {'test_key': 'test_value'})
+        cs.assert_called('POST', '/images/1/metadata',
+                         {"metadata": {'test_key': 'test_value'}})
+
     def test_find(self):
         i = cs.images.find(name="CentOS 5.2")
         self.assertEqual(i.id, 1)
